[MPlayer-cvslog] CVS: main/libmpdemux demuxer.c, 1.206, 1.207 demux_rtp_codec.cpp, 1.7, 1.8 demux_rtp.cpp, 1.28, 1.29 Makefile, 1.96, 1.97 stream.c, 1.78, 1.79 stream_livedotcom.c, 1.2, 1.3

Ross Finlayson CVS syncmail at mplayerhq.hu
Sat Sep 24 00:35:06 CEST 2005


CVS change done by Ross Finlayson CVS

Update of /cvsroot/mplayer/main/libmpdemux
In directory mail:/var2/tmp/cvs-serv28336/libmpdemux

Modified Files:
	demuxer.c demux_rtp_codec.cpp demux_rtp.cpp Makefile stream.c 
	stream_livedotcom.c 
Log Message:
"LIVE.COM Streaming Media" is now called "LIVE555 Streaming Media".


Index: demuxer.c
===================================================================
RCS file: /cvsroot/mplayer/main/libmpdemux/demuxer.c,v
retrieving revision 1.206
retrieving revision 1.207
diff -u -r1.206 -r1.207
--- demuxer.c	19 Sep 2005 16:33:39 -0000	1.206
+++ demuxer.c	23 Sep 2005 22:35:03 -0000	1.207
@@ -114,7 +114,7 @@
   &demuxer_desc_xmms,
 #endif
   &demuxer_desc_mpeg_ty,
-#ifdef STREAMING_LIVE_DOT_COM
+#ifdef STREAMING_LIVE555
   &demuxer_desc_rtp,
 #endif
 #ifdef USE_LIBAVFORMAT

Index: demux_rtp_codec.cpp
===================================================================
RCS file: /cvsroot/mplayer/main/libmpdemux/demux_rtp_codec.cpp,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- demux_rtp_codec.cpp	6 Nov 2003 05:55:52 -0000	1.7
+++ demux_rtp_codec.cpp	23 Sep 2005 22:35:03 -0000	1.8
@@ -1,5 +1,5 @@
 ////////// Codec-specific routines used to interface between "MPlayer"
-////////// and the "LIVE.COM Streaming Media" libraries:
+////////// and the "LIVE555 Streaming Media" libraries:
 
 #include "demux_rtp_internal.h"
 extern "C" {

Index: Makefile
===================================================================
RCS file: /cvsroot/mplayer/main/libmpdemux/Makefile,v
retrieving revision 1.96
retrieving revision 1.97
diff -u -r1.96 -r1.97
--- Makefile	1 Aug 2005 20:16:56 -0000	1.96
+++ Makefile	23 Sep 2005 22:35:04 -0000	1.97
@@ -135,7 +135,7 @@
         realrtsp/sdpplin.c \
         realrtsp/xbuffer.c \
 
-ifeq ($(STREAMING_LIVE_DOT_COM),yes)
+ifeq ($(STREAMING_LIVE555),yes)
 CPLUSPLUSSRCS = demux_rtp.cpp demux_rtp_codec.cpp
 CPLUSPLUSINCLUDE = $(LIVE_INCLUDES)
 endif

Index: stream.c
===================================================================
RCS file: /cvsroot/mplayer/main/libmpdemux/stream.c,v
retrieving revision 1.78
retrieving revision 1.79
diff -u -r1.78 -r1.79
--- stream.c	29 May 2005 12:53:59 -0000	1.78
+++ stream.c	23 Sep 2005 22:35:04 -0000	1.79
@@ -67,7 +67,7 @@
 #ifdef LIBSMBCLIENT
 extern stream_info_t stream_info_smb;
 #endif
-#ifdef STREAMING_LIVE_DOT_COM
+#ifdef STREAMING_LIVE555
 extern stream_info_t stream_info_sdp;
 extern stream_info_t stream_info_rtsp_sip;
 #endif;
@@ -90,7 +90,7 @@
   &stream_info_asf,
   &stream_info_pnm,
   &stream_info_rtsp,
-#ifdef STREAMING_LIVE_DOT_COM
+#ifdef STREAMING_LIVE555
   &stream_info_sdp,
   &stream_info_rtsp_sip,
 #endif

Index: stream_livedotcom.c
===================================================================
RCS file: /cvsroot/mplayer/main/libmpdemux/stream_livedotcom.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- stream_livedotcom.c	20 Jun 2005 08:47:27 -0000	1.2
+++ stream_livedotcom.c	23 Sep 2005 22:35:04 -0000	1.3
@@ -12,7 +12,7 @@
 #include "demuxer.h"
 #include "help_mp.h"
 
-#ifdef STREAMING_LIVE_DOT_COM
+#ifdef STREAMING_LIVE555
 
 extern int network_bandwidth;
 
@@ -38,7 +38,7 @@
   stream->streaming_ctrl->url = check4proxies(url);
   //url_free(url);
 
-  mp_msg(MSGT_OPEN, MSGL_INFO, "STREAM_LIVEDOTCOM, URL: %s\n", stream->url);
+  mp_msg(MSGT_OPEN, MSGL_INFO, "STREAM_LIVE555, URL: %s\n", stream->url);
 
   if(rtsp_streaming_start(stream) < 0) {
     mp_msg(MSGT_NETWORK,MSGL_ERR,"rtsp_streaming_start failed\n");
@@ -100,7 +100,7 @@
   "standard RTSP and SIP",
   "RTSP and SIP",
   "Ross Finlayson",
-  "Uses LIVE.COM streaming library.",
+  "Uses LIVE555 Streaming Media library.",
   open_live_rtsp_sip,
   {"rtsp", "sip", NULL },
   NULL,
@@ -111,7 +111,7 @@
   "SDP stream descriptor",
   "SDP",
   "Ross Finlayson",
-  "Uses live.com streaming library.",
+  "Uses LIVE555 Streaming Media library.",
   open_live_sdp,
   {"sdp", NULL },
   NULL,




More information about the MPlayer-cvslog mailing list
Index: demux_rtp.cpp
===================================================================
RCS file: /cvsroot/mplayer/main/libmpdemux/demux_rtp.cpp,v
retrieving revision 1.28
retrieving revision 1.29
diff -u -r1.28 -r1.29
--- demux_rtp.cpp	5 Aug 2005 19:57:46 -0000	1.28
+++ demux_rtp.cpp	23 Sep 2005 22:35:03 -0000	1.29
@@ -1,5 +1,5 @@
 ////////// Routines (with C-linkage) that interface between "MPlayer"
 ////////// and the "LIVE.COM Streaming Media" libraries:
 
 extern "C" {
 // on MinGW, we must include windows.h before the things it conflicts
@@ -580,11 +580,11 @@
 
 
 demuxer_desc_t demuxer_desc_rtp = {
-  "live.com RTP demuxer",
+  "LIVE555 RTP demuxer",
   "rtp",
   "",
   "Ross Finlayson",
-  "requires live.com library",
+  "requires LIVE555 Streaming Media library",
   DEMUXER_TYPE_RTP,
   0, // no autodetect
   NULL,
@@ -1,5 +1,5 @@
 ////////// Routines (with C-linkage) that interface between "MPlayer"
-////////// and the "LIVE.COM Streaming Media" libraries:
+////////// and the "LIVE555 Streaming Media" libraries:
 
 extern "C" {
